@@ -13,11 +13,11 @@ __END__
 
 =head1 NAME
 
-HTTP::Engine::Middleware::MobileAttribute - documentation is TODO
+HTTP::Engine::Middleware::MobileAttribute - wrapper for HTTP::MobileAttribute
 
 =head1 SYNOPSIS
 
-    my $mw = HTTP::Engine::Middleware->new;
+    my $mw = HTTP::Engine::Middleware->new({method_class => 'HTTP::Engine::Request'});
     $mw->install(qw/ HTTP::Engine::Middleware::MobileAttribute /);
     HTTP::Engine->new(
         interface => {
@@ -26,6 +26,15 @@ HTTP::Engine::Middleware::MobileAttribute - documentation is TODO
         }
     )->run();
 
+=head1 DESCRIPTION
+
+This module injects one method named 'mobile_attribute'.
+This method returns the instance of HTTP::MobileAttribute.
+
+=head1 AUTHORS
+
+Tokuhiro Matsuno
+
 =head1 SEE ALSO
 
 L<HTTP::MobileAttribute>
